@@ -15,7 +15,7 @@ Usage (cli):
 
     $ dig example.com | jc --dig
 
-    or
+or
 
     $ jc dig example.com
 
@@ -101,7 +101,7 @@ Schema:
     ]
 
     [0] naive timestamp if "when" field is parsable, else null
-    [1] timezone aware timestamp availabe for UTC, else null
+    [1] timezone aware timestamp available for UTC, else null
 
 Examples:
 
